/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.contacts.messaging;

import com.liferay.contacts.util.ContactsExtensionsUtil;
import com.liferay.portal.kernel.messaging.BaseMessageListener;
import com.liferay.portal.kernel.messaging.Message;
import com.liferay.portal.kernel.util.MethodKey;
import com.liferay.portal.kernel.util.PortletClassInvoker;
import com.liferay.portal.service.PortletLocalServiceUtil;

/**
 * @author Ryan Park
 */
public class HotDeployMessageListener extends BaseMessageListener {

	@Override
	protected void doReceive(Message message) throws Exception {
		String command = message.getString("command");

		if (command.equals("deploy")) {
			deploy(message);
		}
		else if (command.equals("undeploy")) {
			undeploy(message);
		}
	}

	protected void deploy(Message message) throws Exception {
		String servletContextName = message.getString("servletContextName");

		if (servletContextName.equals("chat-portlet")) {
			registerChatExtension();
		}
		else if (servletContextName.equals("contacts-portlet")) {
			long companyId = message.getLong("companyId");

			if (PortletLocalServiceUtil.hasPortlet(
					companyId, "1_WAR_chatportlet")) {

				registerChatExtension();
			}
		}
	}

	protected void undeploy(Message message) throws Exception {
		String servletContextName = message.getString("servletContextName");

		ContactsExtensionsUtil.unregister(servletContextName);
	}

	protected void registerChatExtension() throws Exception {
		PortletClassInvoker.invoke(
			false, "1_WAR_chatportlet", _registerMethodKey, "contacts-portlet",
			"/chat/view.jsp");
	}

	private MethodKey _registerMethodKey = new MethodKey(
		"com.liferay.chat.util.ChatExtensionsUtil", "register", String.class,
		String.class);

}